/**
 * angular-feeds - v0.0.4 - 2015-04-07 6:38 PM
 * https://github.com/siddii/angular-feeds
 *
 * Copyright (c) 2015
 * Licensed MIT <https://github.com/siddii/angular-feeds/blob/master/LICENSE.txt>
 */
'use strict';

angular.module('feeds-directives', []).directive('feed', ['feedService', '$compile', '$templateCache', '$http', function (feedService, $compile, $templateCache, $http) {
    return  {
        restrict: 'E',
        scope: {
            summary: '=summary'
        },
        controller: ['$scope', '$element', '$attrs', '$timeout', function ($scope, $element, $attrs, $timeout) {
            $scope.$watch('finishedLoading', function (value) {
                if ($attrs.postRender && value) {
                    $timeout(function () {
                        new Function("element", $attrs.postRender + '(element);')($element);
                    }, 0);
                }
            });

            $scope.feeds = [];

            var spinner = $templateCache.get('feed-spinner.html');
            $element.append($compile(spinner)($scope));

            function renderTemplate(templateHTML, feedsObj) {
                $element.append($compile(templateHTML)($scope));
                if (feedsObj) {
                    for (var i = 0; i < feedsObj.length; i++) {
                        $scope.feeds.push(feedsObj[i]);
                    }
                }
            }

            $attrs.$observe('url', function(value){
                feedService.getFeeds(value, $attrs.count, $attrs.recent).then(function(feedsObj) {
                    if ($attrs.templateUrl) {
                        $http.get($attrs.templateUrl, {cache: $templateCache}).success(function(templateHtml) {
                            renderTemplate(templateHtml, feedsObj);
                        });
                    }
                    else {
                        renderTemplate($templateCache.get('feed-list.html'), feedsObj);
                    }
                }, function(error) {
                    console.error('Error loading feed ', error);
                    $scope.error = error;
                    renderTemplate($templateCache.get('feed-list.html'));
                }).finally(function() {
                    $element.find('.spinner').slideUp();
                    $scope.$evalAsync('finishedLoading = true')
                });
            });
        }]
    }
}]);

'use strict';

angular.module('feeds', ['feeds-services', 'feeds-directives']);
'use strict';

angular.module('feeds-services', []).factory('feedService', ['$q', '$sce', 'feedCache', function ($q, $sce, feedCache) {

        function sanitizeFeedEntry(feedEntry) {
            feedEntry.title = $sce.trustAsHtml(feedEntry.title);
            feedEntry.contentSnippet = $sce.trustAsHtml(feedEntry.contentSnippet);
            feedEntry.content = $sce.trustAsHtml(feedEntry.content);
            feedEntry.publishedDate = new Date(feedEntry.publishedDate).getTime();
            feedEntry.link = $sce.trustAsHtml(feedEntry.link);
            return feedEntry;
        }

        var getFeeds = function (feedURL, count, recent) {
            var deferred = $q.defer();

            if (recent == "false" && feedCache.hasCache(feedURL)) {
                 deferred.resolve(feedCache.get(feedURL));
            } else {
                var randomNum = Math.floor((Math.random() * 10000) + 1);
                var newFeedURL = feedURL + "?&t=" + new Date().getTime() + randomNum;

                var feed = new google.feeds.Feed(newFeedURL);
                if (count) {
                    feed.includeHistoricalEntries();
                    feed.setNumEntries(count);
                }

                feed.load(function (response) {
                    if (response.error) {
                        deferred.reject(response.error);
                    }
                    else {
                        feedCache.set(feedURL, response.feed.entries);
                        for (var i = 0; i < response.feed.entries.length; i++) {
                            sanitizeFeedEntry(response.feed.entries[i]);
                        }
                        deferred.resolve(response.feed.entries);
                    }
                });
            }
            return deferred.promise;
        };

        return {
            getFeeds: getFeeds
        };
    }])
    .factory('feedCache', function () {
        var CACHE_INTERVAL = 1000 * 60 * 30; // 30 minutes

        function cacheTimes() {
            if ('CACHE_TIMES' in localStorage) {
                return angular.fromJson(localStorage['CACHE_TIMES']);
            }
            return {};
        }

        function hasCache(name) {
            var CACHE_TIMES = cacheTimes();
            return name in CACHE_TIMES && name in localStorage && new Date().getTime() - CACHE_TIMES[name] < CACHE_INTERVAL;
        }

        return {
            set: function (name, obj) {
                localStorage[name] = angular.toJson(obj);
                var CACHE_TIMES = cacheTimes();
                CACHE_TIMES[name] = new Date().getTime();
                localStorage['CACHE_TIMES'] = angular.toJson(CACHE_TIMES);
            },
            get: function (name) {
                if (hasCache(name)) {
                    return angular.fromJson(localStorage[name]);
                }
                return null;
            },
            hasCache: hasCache
        };
    });
angular.module('feeds').run(['$templateCache', function($templateCache) {
    'use strict';


    $templateCache.put('feed-list.html',
        "<div class='speakers'>\n" +
        "    <div ng-show=\"error\" class=\"alert alert-danger\">\n" +
        "        <h5 class=\"text-center\">Oops... Something bad happened, please try later :(</h5>\n" +
        "    </div>\n" +
        "\n" +
        "    <ul class=\"media-list\">\n" +
        "        <li ng-repeat=\"feed in feeds | orderBy:publishedDate:reverse\" class=\"media\">\n" +
        "            <div>\n" +
        "                <a href='' class='head-title' ng-click='isCollapsed = !isCollapsed'><h4 class=\"media-heading\" ng-bind-html=\"feed.title\"></h4></a>" +
        "            <div class='collapsedContent' ng-show='isCollapsed'>" +
        "                <p class='img-hide' ng-bind-html=\"feed.content\"></p>\n" +
        "            </div></div>\n" +
        "            <hr ng-if=\"!$last\"/>\n" +
        "        </li>\n" +
        "    </ul>\n" +
        "</div>"
    );


    $templateCache.put('feed-circle.html',
        "<div class='speakers'>\n" +
        "    <div ng-show=\"error\" class=\"alert alert-danger\">\n" +
        "        <h5 class=\"text-center\">Oops... Something bad happened, please try later :(</h5>\n" +
        "    </div>\n" +
        "\n" +
        "    <ul class=\"media-list\">\n" +
        "        <li ng-repeat=\"feed in feeds | orderBy:publishedDate:reverse\" class=\"media\">\n" +
        "            <div>\n" +
        "                <a href='' class='head-title' ng-click='isCollapsed = !isCollapsed'><p class='img-circle img-responsive text-hide' ng-bind-html=\"feed.content\"></p><h4 class=\"media-heading\" ng-bind-html=\"feed.title\"></h4><p class='subtitle-speakers' ng-bind-html=\"feed.contentSnippet\"></p></a>" +
        "            <div class='collapsedContent' ng-show='isCollapsed'>" +
        "                <p class='img-hide' ng-bind-html=\"feed.content\"></p>\n" +
        "            </div></div>\n" +
        "            <hr ng-if=\"!$last\"/>\n" +
        "        </li>\n" +
        "    </ul>\n" +
        "</div>"
    );

    $templateCache.put('feed-square.html',
        "<div class='sponsors'>\n" +
        "    <div ng-show=\"error\" class=\"alert alert-danger\">\n" +
        "        <h5 class=\"text-center\">Oops... Something bad happened, please try later :(</h5>\n" +
        "    </div>\n" +
        "    <ul>\n" +
        "        <li class='head-main'>\n" +
        "            <div class=''>" +
        "               <ul class=\"media-list\">\n" +
        "                   <li ng-repeat=\"feed in feeds | orderBy:publishedDate:reverse\" class=\"media\">\n" +
        "                       <div>\n" +
        "                           <a href='' class='head-title' ng-click='isCollapsed1 = !isCollapsed1'><p class='img-responsive text-hide' ng-bind-html=\"feed.content\"></p><h4 class=\"media-heading\" ng-bind-html=\"feed.title\"></h4><p class='subtitle-speakers' ng-bind-html=\"feed.contentSnippet\"></p></a>" +
        "                       <div class='collapsedContent' ng-show='isCollapsed1'>" +
        "                            <p class='img-hide' ng-bind-html=\"feed.content\"></p>\n" +
        "                       </div></div>\n" +
        "                       <hr ng-if=\"!$last\"/>\n" +
        "                   </li>\n" +
        "               </ul>\n" +
        "            </div>\n" +
        "            <hr ng-if=\"!$last\"/>\n" +
        "        </li>\n" +
        "    </ul>\n" +
        "</div>"
    );


    /** Same feed-square.html But showing images**/
    $templateCache.put('feed-square2.html',
        "<div class='sponsors'>\n" +
        "    <div ng-show=\"error\" class=\"alert alert-danger\">\n" +
        "        <h5 class=\"text-center\">Oops... Something bad happened, please try later :(</h5>\n" +
        "    </div>\n" +
        "    <ul>\n" +
        "        <li class='head-main'>\n" +
        "            <div class=''>" +
        "               <ul class=\"media-list\">\n" +
        "                   <li ng-repeat=\"feed in feeds | orderBy:publishedDate:reverse\" class=\"media\">\n" +
        "                       <div>\n" +
        "                           <a href='' class='head-title' ng-click='isCollapsed1 = !isCollapsed1'><p class='img-responsive text-hide' ng-bind-html=\"feed.content\"></p><h4 class=\"media-heading\" ng-bind-html=\"feed.title\"></h4><p class='subtitle-speakers' ng-bind-html=\"feed.contentSnippet\"></p></a>" +
        "                       <div class='collapsedContent awards' ng-show='isCollapsed1'>" +
        "                            <p class='img-hide' ng-bind-html=\"feed.content\"></p>\n" +
        "                       </div></div>\n" +
        "                       <hr ng-if=\"!$last\"/>\n" +
        "                   </li>\n" +
        "               </ul>\n" +
        "            </div>\n" +
        "            <hr ng-if=\"!$last\"/>\n" +
        "        </li>\n" +
        "    </ul>\n" +
        "</div>"
    );

    /** Same feed-square.html but Showing a previous picture**/
    $templateCache.put('feed-square3.html',
        "<div class='sponsors'>\n" +
        "    <div ng-show=\"error\" class=\"alert alert-danger\">\n" +
        "        <h5 class=\"text-center\">Oops... Something bad happened, please try later :(</h5>\n" +
        "    </div>\n" +
        "    <ul>\n" +
        "        <li class='head-main'>\n" +
        "            <div class=''>" +
        "               <ul class=\"media-list\">\n" +
        "                   <li ng-repeat=\"feed in feeds | orderBy:publishedDate:reverse\" class=\"media padding-bottom-20rem\">\n" +
        "                       <div>\n" +
        "                           <a href='' class='head-title' ng-click='isCollapsed1 = !isCollapsed1'><p class='img-responsive text-hide' ng-bind-html=\"feed.content\"></p><h4 class=\"media-heading\" ng-bind-html=\"feed.title\"></h4><p class='subtitle-speakers' ng-bind-html=\"feed.contentSnippet\"></p></a>" +
        "                       <div class='collapsedContent img-hidden' ng-show='isCollapsed1'>" +
        "                            <p class='' ng-bind-html=\"feed.content\"></p>\n" +
        "                       </div></div>\n" +
        "                       <hr ng-if=\"!$last\"/>\n" +
        "                   </li>\n" +
        "               </ul>\n" +
        "            </div>\n" +
        "            <hr ng-if=\"!$last\"/>\n" +
        "        </li>\n" +
        "    </ul>\n" +
        "</div>"
    );


    $templateCache.put('feed-grid.html',
        "<div class='row text-center grid'>\n" +
        "            <div class=''>" +
        "                   <div ng-repeat=\"feed in feeds | orderBy:publishedDate:reverse\" class='col-xs-4'>\n" +
        "                       <div>\n" +
        "                           <a href='' class='head-title'><p class='img-responsive text-hide' ng-bind-html=\"feed.content\"></p><h4 class=\"media-heading\" ng-bind-html=\"feed.title\"></h4><p class='subtitle-speakers' ng-bind-html=\"feed.contentSnippet\"></p></a>" +
        "                       <div class='collapsedContent' ng-show='isCollapsed1'>" +
        "                            <p class='img-hide' ng-bind-html=\"feed.content\"></p>\n" +
        "                       </div></div>\n" +
        "                   </div>\n" +
        "            </div>\n" +
        "</div>"
    );

    $templateCache.put('feed-full.html',
        "<div class='full'>\n" +
        "    <div ng-show=\"error\" class=\"alert alert-danger\">\n" +
        "        <h5 class=\"text-center\">Oops... Something bad happened, please try later :(</h5>\n" +
        "    </div>\n" +
        "\n" +
        "    <ul class=\"media-list\">\n" +
        "        <li ng-repeat=\"feed in feeds | orderBy:publishedDate:reverse\" class=\"media\">\n" +
        "            <div class=\"media-body\">\n" +
        "                <p class='full-text' ng-bind-html=\"feed.content\"></p>\n" +
        "            </div>\n" +
        "            <hr ng-if=\"!$last\"/>\n" +
        "        </li>\n" +
        "    </ul>\n" +
        "</div>"
    );

    $templateCache.put('feed-spinner.html',
        "<div class=\"spinner\">\n" +
        "    <div class=\"bar1\"></div>\n" +
        "    <div class=\"bar2\"></div>\n" +
        "    <div class=\"bar3\"></div>\n" +
        "    <div class=\"bar4\"></div>\n" +
        "    <div class=\"bar5\"></div>\n" +
        "    <div class=\"bar6\"></div>\n" +
        "    <div class=\"bar7\"></div>\n" +
        "    <div class=\"bar8\"></div>\n" +
        "</div>\n"
    );

}]);

