'use strict';

app.controller('friendController',
    ['$scope', '$rootScope', '$log', '$location', 'PROPERTIES', 'sharedDataService', '$routeParams', 'friendService', 'attendeeService', '$cordovaBarcodeScanner', '$cordovaInAppBrowser', '$cordovaContacts', '$filter', 'SweetAlert',
        function ($scope, $rootScope, $log, $location, PROPERTIES, $sharedDataService, $routeParams, $friendService, $attendeeService, $cordovaBarcodeScanner, $cordovaInAppBrowser, $cordovaContacts, $filter, SweetAlert) {

            $log.debug("friendController");
            $scope.showHide = false;
            $rootScope.bg = 'bg';
            $scope.tcURL = PROPERTIES.termsURL;
            $scope.privacyURL = PROPERTIES.privacyURL;

            var options = {
                location: 'yes',
                clearcache: 'yes',
                toolbar: 'no'
            };

            $scope.openNetwork = $sharedDataService.getUser().openNetwork;
            $scope.shareMobile = $sharedDataService.getUser().shareMobile;

            $scope.setOpenNetworking = function () {
                var profile = $sharedDataService.getUser();
                profile.openNetwork = $scope.openNetwork;
                profile.shareMobile = $scope.shareMobile;

                $attendeeService.save(profile, function (success, response) {
                    $log.debug(response);
                    if (success) {
                        $scope.errorModal = true;
                        $scope.error = "Your open network preferences have been saved.";
                        $sharedDataService.setUser(response);
                    } else {
                        $scope.errorModal = true;
                        $scope.error = "Sorry there has been an issue updating your profile, please try again later.";
                    }
                });
            }

            $scope.formatFriends = function () {
                $scope.members = _.reduce(
                    $scope.friends,
                    function (output, name) {
                        var lCase = name.friend.lastName.toLowerCase();
                        if (output[lCase[0]]) //if lCase is a key
                            output[lCase[0]].push(name); //Add name to its list
                        else
                            output[lCase[0]] = [name]; // Else add a key
                        return output;
                    },

                    {}
                );
            }

            $scope.formatAttendees = function () {
                $scope.members = _.reduce(
                    $scope.friends,
                    function (output, name) {
                        var lCase = name.lastName.toLowerCase();
                        if (output[lCase[0]]) //if lCase is a key
                            output[lCase[0]].push(name); //Add name to its list
                        else
                            output[lCase[0]] = [name]; // Else add a key
                        return output;
                    },

                    {}
                );
            }
            if ($routeParams.type == "mine") {
                $friendService.getForEvent($sharedDataService.getEventDetailId(), $sharedDataService.getAttendeeId(), function (success, result) {
                    if (success) {
                        $scope.friends = result;
                        $scope.formatFriends();
                    }
                });
            } else if ($routeParams.type == "open") {
                $attendeeService.openNetwork(function (success, result) {
                    if (success) {
                        $scope.friends = result;
                        $scope.formatAttendees();
                    }
                });
            }

            $scope.addConnection = function (friendId, openNetwork) {

                var friendRequest = {eventId: $sharedDataService.getEventDetailId(), attendeeId: $sharedDataService.getAttendeeId(), friendId: friendId, openNetworking: openNetwork};

                $friendService.makeFriend(friendRequest, function (success, response) {
                    $log.debug(response);
                    if (success) {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "This connection has been added.";
                    } else {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "Sorry there has been an issue adding your connection, please try again later.";
                    }
                });
                $scope.showHide = true;
            };

            $scope.openURL = function (url) {
                $cordovaInAppBrowser.open(url, '_blank', options)
                    .then(function (event) {
                        // success
                    })
                    .catch(function (event) {
                        // error
                    });

                $cordovaInAppBrowser.close();
            };

            $scope.makeConnection = function () {

                document.addEventListener("deviceready", function () {

                    SweetAlert.swal("Move the scanner over the QR code shown on the profile page on the person you are connecting with.");

                    $cordovaBarcodeScanner
                        .scan()
                        .then(function (result) {
                            if (result.cancelled === 0) {
                                if ($filter('limitTo')(result.text, 4, 0) == "http") {
                                    $scope.openURL(result.text);
                                } else if ($filter('limitTo')(result.text, 3, 0) == "www") {
                                    $scope.openURL("http://" + result.text);
                                } else {
                                    $scope.addConnection(result.text, false);
                                }
                            }
                        }, function (error) {
                            $scope.errorModal = true;
                            $scope.error = "Scanning failed: " + error;
                        });

                }, false);
            };

            $scope.addContact = function (friend) {
                $log.debug(friend);

                document.addEventListener("deviceready", function () {

                    var opts = {
                        filter: friend.lastName,
                        multiple: true,
                        fields: ['displayName', 'name'],
                        desiredFields: ['id', 'phoneNumbers']
                    };

                    var contact = {};
                    contact.name = {givenName: friend.firstName, familyName: friend.lastName};
                    var phoneNumbers = [];
                    phoneNumbers[0] = new ContactField('mobile', friend.mobile, true);
                    contact.phoneNumbers = phoneNumbers;
                    var emails = [];
                    emails[0] = new ContactField('email', friend.email, true);
                    contact.emails = emails;
                    var urls = [];
                    urls[0] = new ContactField('website', friend.website, true);
                    contact.urls = urls;
                    contact.organizations = [
                        new ContactOrganization(true, 'work', friend.companyName, '', friend.position)
                    ];

                    $cordovaContacts.find(opts).then(function (contactsFound) {
                        var contactFound = false;
                        for (var j = 0, lenJ = contactsFound.length; j < lenJ; j++) {
                            if (checkNested(contactsFound[j], "phoneNumbers")) {
                                for (var i = 0, lenI = contactsFound[j].phoneNumbers.length; i < lenI; i++) {
                                    if (angular.equals(contactsFound[j].phoneNumbers[i].value, friend.mobile)) {
                                        contactFound = true;
                                        break;
                                    }
                                }
                            }
                            if (contactFound) {
                                break;
                            }
                        }

                        if (contactFound) {
                            $scope.errorModal = true;
                            $scope.error = "Contact already in your phone.";
                        } else {
                            $cordovaContacts.save(contact).then(function (result) {
                                $scope.errorModal = true;
                                $scope.error = "Contact details saved to your phone.";
                            }, function (err) {
                                $scope.errorModal = true;
                                $scope.error = err;
                            });
                        }
                    });
                }, false);
            };

            $scope.closeModalDialog = function () {
                $scope.errorModal = !$scope.errorModal;
            };
        }]);