'use strict';

app.controller('loginController',
    ['$scope', '$rootScope', '$log', '$location', 'PROPERTIES', 'loginService', 'attendeeService', '$cordovaPushV5', '$cordovaToast', '$cordovaDevice', '$cordovaOauth', '$http', '$uibModal',
        function ($scope, $rootScope, $log, $location, PROPERTIES, $loginService, $attendeeService, $cordovaPushV5, $cordovaToast, $cordovaDevice, $cordovaOauth, $http, $uibModal) {

            $log.debug("loginController");
            $rootScope.bg = '';

            $scope.login = function (showModal) {

                $loginService.ClearCredentials();

                $scope.showHide = true;

                setTimeout(function () {
                    $loginService.Login($scope.email, $scope.pin, function (success, response) {
                        $log.debug(response);

                        if (success) {
                            $rootScope.refreshFlag = false;

                            $loginService.SetCredentials($scope.email, $scope.pin, response);

                            document.addEventListener("deviceready", function () {
                                var options = {
                                    android: {
                                        senderID: PROPERTIES.GCM
                                    },
                                    ios: {
                                        alert: true,
                                        badge: true,
                                        sound: false,
                                        clearBadge: true
                                    },
                                    windows: {}
                                };

                                $cordovaPushV5.initialize(options).then(function (deviceToken) {
                                    $cordovaPushV5.register().then(function (deviceToken) {
                                        $log.debug("deviceToken: " + deviceToken);

                                        response.attendee.deviceToken = deviceToken;
                                        response.attendee.deviceType = $cordovaDevice.getPlatform();

                                        $attendeeService.save(response.attendee, function (result) {
                                            $sharedDataService.setUser(result);
                                        });

                                        $cordovaPushV5.onError();
                                        $cordovaPushV5.onNotification();

                                    }, function (err) {
                                        $log.debug('register error: ' + err)
                                    });
                                }, function (err) {
                                    $log.debug('initialize error: ' + err)
                                });
                            });

                            $scope.showHide = true;

                            $location.path('/');

                        } else {
                            $scope.showHide = false;
                            $scope.errorModal = true;
                            $scope.error = "Your email or PIN are is not correct";
                        }
                    });

                }, 1000);

            };

            $scope.loginLinkedIn = function () {

                $scope.showHide = true;

                document.addEventListener("deviceready", function () {
                    $cordovaOauth.linkedin(PROPERTIES.LINKEDIN_CLIENTKEY, PROPERTIES.LINKEDIN_SECRET, ["r_basicprofile", "r_emailaddress"], "K8fghkgdf6hgf7gdfs34", {redirect_uri: "http://localhost/callback"}).then(function (result) {
                        $http.get("https://api.linkedin.com/v1/people/~:(email-address,first-name,last-name)?format=json&oauth2_access_token=" + result.access_token).then(function (result) {
                            //alert(JSON.stringify(result));
                            $scope.showHide = true;

                            var registerRequest = {applicationId: PROPERTIES.applicationId, attendee: {email: result.data.emailAddress, firstName: result.data.firstName, lastName: result.data.lastName}};

                            //alert("1");
                            //alert(JSON.stringify(registerRequest));

                            $attendeeService.register(registerRequest, function (success, response) {
                                //alert("2");
                                $log.debug(response);
                                if (success) {
                                    //alert("3");
                                    //alert(JSON.stringify(response));
                                    $scope.email = response.email;
                                    $scope.pin = response.validationNumber;
                                    // alert("3.1");
                                    $scope.login(true);
                                } else {
                                    //alert("4");
                                    $scope.showHide = false;
                                    $scope.errorModal = true;
                                    $log.debug($scope.showHide);
                                    $scope.error = response.message;
                                    //alert(JSON.stringify(response));
                                }
                            });

                        }, function (err) {
                            //alert(JSON.stringify(err));
                            $scope.showHide = false;
                            $scope.errorModal = true;
                            $scope.error = "We are unable to login via LinkedLin, try again later or create an account";
                            $location.path('/login');
                        });
                    });
                });
            };

            $scope.forgottenPin = function (event) {
                $loginService.forgottenPin($scope.email,
                    function (success, result) {
                        if (success) {
                            $scope.showHide = false;
                            $scope.errorModal = true;
                            $scope.error = "Your PIN has been sent to your email address.";

                        } else {
                            $scope.showHide = false;
                            $scope.errorModal = true;
                            $scope.error = "Unable to reset your PIN, please check that you are registered for this event.";
                        }

                    });
                $scope.showHide = true;
            };

            $scope.closeModalDialog = function () {
                $scope.errorModal = !$scope.errorModal;
            };

            $scope.logout = function (event) {
                $log.debug("logout");
                $loginService.ClearCredentials();
                $location.path('/login');
            };

            $scope.register = function (event) {
                $log.debug("register");
                $location.path('/register');
            };

            $scope.forgottenPassword = function (event) {
                $log.debug("forgottenPassword");
                $location.path('/forgottenPassword');
            };

            $rootScope.$on('$cordovaPushV5:notificationReceived', function (event, data) {
                $cordovaToast.showLongCenter(data.message).then(function (success) {
                    // success
                }, function (error) {
                    // error
                });
                if (Device.isOniOS()) {
                    if (data.additionalData.badge) {
                        $cordovaPushV5.setBadgeNumber(NewNumber).then(function (result) {
                        }, function (err) {
                        });
                    }
                }

                $cordovaPushV5.finish().then(function (result) {
                }, function (err) {
                });
            });

            $rootScope.$on('$cordovaPushV5:errorOccurred', function (event, error) {
                // handle error
            });

            $log.debug(localStorage["authInformation"]);
            if ("authInformation" in localStorage && localStorage["authInformation"] != null) {
                var authArray = localStorage["authInformation"].split(':');

                $scope.email = authArray[0];
                $scope.pin = authArray[1];
                $scope.login(false);
            }

        }]);