'use strict';

app.controller('programController',
    ['$scope', '$rootScope', '$log', '$location', 'sharedDataService', 'sessionService', '$routeParams', '$filter', 'checkinService',
        function ($scope, $rootScope, $log, $location, $sharedDataService, $sessionService, $routeParams, $filter, $checkinService) {

            $log.debug("programController");

            $scope.listTypeHeading = '';
            $rootScope.bg = 'bg';
            $scope.showSession = 0;

                $scope.formatForDays = function () {

                $scope.members = _.reduce(
                    $scope.sessions,
                    function (output, session) {
                        var date = $filter('date')(session.startDate, "dd/MM/yyyy");
                        if (output[date]) //if lCase is a key
                            output[date].push(session); //Add date to its list
                        else
                            output[date] = [session]; // Else add a key
                        return output;
                    },

                    {}
                );
            }

            $scope.listType = $routeParams.type;

            if ($routeParams.type == "mine") {
                $sessionService.getMySessions($sharedDataService.getEventDetailId(), $sharedDataService.getAttendeeId(), function (success, result) {
                    $scope.listTypeHeading = 'My Sessions';
                    $scope.sessions = result;
                    $scope.formatForDays();
                });
            } else if ($routeParams.type == "checkin") {
                $sessionService.getEventSessions($sharedDataService.getEventDetailId(), $sharedDataService.getAttendeeId(), function (success, result) {
                    $scope.sessions = result;
                    $scope.sessions = $scope.sessions.filter(function (obj) {
                        return (new Date() >= obj.checkinStart && new Date() <= obj.checkinEnd);
                    });
                    $scope.formatForDays();
                });
            } else if ($routeParams.type == "current") {
                $sessionService.getEventSessions($sharedDataService.getEventDetailId(), $sharedDataService.getAttendeeId(), function (success, result) {
                    $scope.listTypeHeading = 'Current Sessions';
                    $scope.sessions = result;
                    $scope.sessions = $scope.sessions.filter(function (obj) {
                        return $filter('date')(obj.startDate, "dd/MM/yyyy") == $filter('date')(new Date(), "dd/MM/yyyy") && $filter('date')(obj.startDate, "HHmm") >= $filter('date')(new Date(), "HHmm");
                    });
                    $scope.formatForDays();
                });
            } else {
                $sessionService.getEventSessions($sharedDataService.getEventDetailId(), $sharedDataService.getAttendeeId(), function (success, result) {
                    $scope.listTypeHeading = 'All Sessions';
                    $scope.sessions = result;
                    $scope.formatForDays();
                });
            }

            $scope.isCollapsed = false;

            $scope.checkinAvailable = function (checkinStart, checkinEnd) {
                // Checkin can be 5 minutes before until the end of the session
                return (new Date() >= checkinStart && new Date() <= checkinEnd);
            };

            $scope.formattedSessionTime = function (startDate, endDate) {
                return "<p>" + $filter('date')(startDate, "fullDate") + "</p>" + "<p>" + $filter('date')(startDate, "hh:mm a") + " - " + $filter('date')(endDate, "hh:mm a") + "</p>";
            }

            $scope.formattedSessionDuration = function (duration) {
                return "<p>Duration " + duration / 60 + "h</p>";
            }

            $scope.formattedSessionHeading = function (session) {
                return $filter('lowercase')($filter('date')(session.startDate, "hh:mma")) + " " + session.title;
            }

            $scope.checkin = function (sessionId) {
                $scope.showHide = true;
                $checkinService.checkin(sessionId, function (success, response) {
                    $log.debug(response);
                    $scope.showHide = false;
                    if (success) {
                        $scope.errorModal = true;
                        $scope.error = "Thanks for checking into this session.";
                        $scope.showSession = sessionId;
                    } else {
                        $scope.errorModal = true;
                        $scope.error = "Sorry there has been an issue adding your check in, please try again later.";
                    }
                });
            };

            $scope.getFullDescription = function (x) {
                return "<b>Description: </b>" + x.description;
            }

            $scope.rate = function (sessionId, rating) {
                $scope.showHide = true;
                $checkinService.rate(sessionId, rating, function (success, response) {
                    $log.debug(response);
                    $scope.showHide = false;
                    if (success) {
                        $scope.errorModal = true;
                        $scope.error = "Thanks for rating this session.";
                    } else {
                        $scope.errorModal = true;
                        $scope.error = "Sorry there has been an issue adding your rating, please try again later.";
                    }
                });
            };

            $scope.remind = function (sessionId) {
                $scope.showHide = true;
                $checkinService.remind(sessionId, function (success, response) {
                    $log.debug(response);
                    $scope.showHide = false;
                    if (success) {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "A reminder for this session has been set and you will receive it 5 minutes before the scheduled start time.";
                    } else {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "Sorry there has been an issue adding your reminder, please try again later.";
                    }
                });
            };

            $scope.remove = function (sessionId) {
                $scope.showHide = true;
                $checkinService.remove(sessionId, function (success, response) {
                    $log.debug(response);
                    if (success) {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "This session has been removed form your program.";

                        $sessionService.getMySessions($sharedDataService.getEventDetailId(), $sharedDataService.getAttendeeId(), function (success, result) {
                            $scope.sessions = result;
                            $scope.formatForDays();
                        });

                    } else {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "Sorry there has been an issue removing your session, please try again later.";
                    }
                });
            };

            $scope.add = function (sessionId) {
                $checkinService.add(sessionId, function (success, response) {
                    $scope.showHide = true;
                    $log.debug(response);
                    if (success) {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "This session has been added to your program.";
                    } else {
                        $scope.showHide = false;
                        $scope.errorModal = true;
                        $scope.error = "Sorry there has been an issue adding this session, please try again later.";
                    }
                });
            };

            $scope.closeModalDialog = function () {
                $scope.errorModal = !$scope.errorModal;
            };
        }]);