var app = angular.module("eventApp", ['ngRoute', 'ui.bootstrap', 'ngCookies', 'feeds', 'angular.filter', 'monospaced.qrcode', 'ngSanitize', 'ngCordova', 'angular-cache', 'ngCordovaOauth', 'oitozero.ngSweetAlert', 'ngtweet',]);

app.config(function ($routeProvider, $logProvider) {
    $routeProvider
        .when('/login', {templateUrl: 'view/login.html', reloadOnSearch: false})
        .when('/', {templateUrl: 'view/listEvents.html', reloadOnSearch: false})
        .when('/eventDetail', {templateUrl: 'view/homeEvent.html', reloadOnSearch: false})
        .when('/program', {templateUrl: 'view/homeProgram.html', reloadOnSearch: false})
        .when('/programDetail', {templateUrl: 'view/detailProgram.html', reloadOnSearch: false})
        .when('/listSessions/:type', {templateUrl: 'view/sessions.html', reloadOnSearch: false})
        .when('/feedList/:feedName', {templateUrl: 'view/feedList.html', reloadOnSearch: false})
        .when('/profile', {templateUrl: 'view/profileEdit.html', reloadOnSearch: false})
        .when('/tableplan', {templateUrl: 'view/tableplan.html', reloadOnSearch: false})
        .when('/friends', {templateUrl: 'view/homeFriends.html', reloadOnSearch: false})
        .when('/question', {templateUrl: 'view/question.html', reloadOnSearch: false})
        .when('/twitter', {templateUrl: 'view/twitter.html', reloadOnSearch: false})
        .when('/listMyFriends/:type', {templateUrl: 'view/listMyFriends.html', reloadOnSearch: false})
        .when('/listOpenFriends/:type', {templateUrl: 'view/listOpenFriends.html', reloadOnSearch: false})
        .when('/register', {templateUrl: 'view/register.html', reloadOnSearch: false})
        .when('/registerSuccess', {templateUrl: 'view/registerSuccess.html', reloadOnSearch: false})
        .when('/forgottenPassword', {templateUrl: 'view/forgottenPassword.html', reloadOnSearch: false})

    $logProvider.debugEnabled(true);

});

app.run(['$rootScope', 'sharedDataService',
    function ($rootScope, sharedDataService) {

        $rootScope.getEventDetailId = function (sharedDataService) {
            return sharedDataService.getEventDetailId();
        };
    }]);

app.run(['$rootScope', '$location', '$cookieStore', '$http', 'sharedDataService',
    function ($rootScope, $location, $cookieStore, $http, sharedDataService) {

        $rootScope.globals = $cookieStore.get('globals') || {};

        if ($rootScope.globals.currentUser) {
            $http.defaults.headers.common['Authorization'] = 'Basic ' + $rootScope.globals.currentUser.authdata; // jshint ignore:line
        }

        $rootScope.$on('$locationChangeStart', function (event, next, current) {
            if ($location.path() == '/register') {
                $location.path('/register');
            } else if ($location.path() == '/registerSuccess') {
                $location.path('/registerSuccess');
            } else if ($location.path() == '/forgottenPassword') {
                $location.path('/forgottenPassword');
            } else if ($location.path() !== '/login' && sharedDataService.getLoginResponse() == null) {
                $location.path('/login');
            } else if ($location.path() !== '/login' && sharedDataService.getLoginResponse() != null && typeof $rootScope.refreshFlag == 'undefined') {
                $rootScope.refreshFlag = false;
                $location.path('/');
            }
        });
    }]);

app.directive('starRating', function () {
    return {
        scope: {
            rating: '=',
            maxRating: '@',
            readOnly: '@',
            click: "&"
        },
        restrict: 'EA',
        template: "<div style='display: inline-block; margin: 0px; padding: 0px; cursor:pointer;' ng-repeat='idx in maxRatings track by $index'> \
                    <img ng-src='{{((_rating) <= $index) && \"images/star-empty-lg.png\" || \"images/star-fill-lg.png\"}}' \
                    ng-Click='isolatedClick($index + 1)' ></img> \
            </div>",
        compile: function (element, attrs) {
            if (!attrs.maxRating || (Number(attrs.maxRating) <= 0)) {
                attrs.maxRating = '5';
            }
            ;
        },
        controller: function ($scope, $element, $attrs) {
            $scope.maxRatings = [];

            for (var i = 1; i <= $scope.maxRating; i++) {
                $scope.maxRatings.push({});
            }
            ;

            $scope._rating = $scope.rating;

            $scope.isolatedClick = function (param) {
                if ($scope.readOnly == 'true') return;

                $scope.rating = $scope._rating = param;
                $scope.hoverValue = 0;
                $scope.click({
                    param: param
                });
            };
        }
    };
});

app.directive('pinInput', function () {
    return {
        restrict: 'EA',
        template: '<input name="{{inputName}}" ng-minlength="4" ng-maxlength="4" maxlength="4" ng-model="inputValue" id="{{inputName}}" class="form-control" style="height: 46px;" autocomplete="off" required />',
        scope: {
            inputValue: '=',
            inputName: '='
        },
        link: function (scope) {
            scope.$watch('inputValue', function (newValue, oldValue) {
                var arr = String(newValue).split("");
                if (arr.length === 0) return;
                if (arr.length > 4) return;
                if (isNaN(newValue)) {
                    scope.inputValue = oldValue;
                }
            });
        }
    };
});

app.filter('isEmpty', function () {
    var bar;
    return function (obj) {
        for (bar in obj) {
            if (obj.hasOwnProperty(bar)) {
                return false;
            }
        }
        return true;
    };
});

app.filter('titlecase', function () {
    return function (input) {
        var smallWords = /^(a|an|and|as|at|but|by|en|for|if|in|nor|of|on|or|per|the|to|vs?\.?|via)$/i;

        input = input.toLowerCase();
        return input.replace(/[A-Za-z0-9\u00C0-\u00FF]+[^\s-]*/g, function (match, index, title) {
            if (index > 0 && index + match.length !== title.length &&
                match.search(smallWords) > -1 && title.charAt(index - 2) !== ":" &&
                (title.charAt(index + match.length) !== '-' || title.charAt(index - 1) === '-') &&
                title.charAt(index - 1).search(/[^\s-]/) < 0) {
                return match.toLowerCase();
            }

            if (match.substr(1).search(/[A-Z]|\../) > -1) {
                return match;
            }

            return match.charAt(0).toUpperCase() + match.substr(1);
        });
    }
});