var sharedDataService = ['$window', function ($window) {

    var setSession = function (key, value) {
        try {
            if ($window.Storage) {
                $window.sessionStorage.setItem(key, $window.JSON.stringify(value));
                return true;
            } else {
                return false;
            }
        } catch (error) {
            console.error(error, error.message);
        }
    };

    var getSession = function (key) {
        try {
            if ($window.Storage) {
                return $window.JSON.parse($window.sessionStorage.getItem(key));
            } else {
                return null;
            }
        } catch (error) {
            console.error(error, error.message);
        }
    };

    var removeSession = function (key) {
        try {
            if ($window.Storage) {
                return $window.sessionStorage.removeItem(key);
            } else {
                return null;
            }
        } catch (error) {
            console.error(error, error.message);
        }
    };

    var factory = {};

    factory.clearSession = function () {
        try {
            if ($window.Storage) {
                return $window.sessionStorage.clear();
            } else {
                return false;
            }
        } catch (error) {
            console.error(error, error.message);
        }
    };

    factory.getUser = function () {
        return getSession("attendee");
    };

    factory.getAttendeeId = function () {
        return factory.getUser().attendeeId;
    };

    factory.setUser = function (value) {
        setSession('attendee', value);
    };

    factory.getLoginResponse = function () {
        return getSession("loginResponse");
    };

    factory.setLoginResponse = function (value) {
        setSession('loginResponse', value);
        setSession('attendee', value.attendee);
    };

    factory.getEventDetailId = function () {
        return factory.getEventDetail().event.eventId;
    };

    factory.getEventDetailSessions = function () {
        return factory.getEventDetail().sessions;
    };

    factory.getEventDetail = function () {
        return getSession("eventDetail");
    };

    factory.setEventDetail = function (value) {
        setSession('eventDetail', value);
    };

    factory.getFeeds = function () {
        var value = factory.getEventDetail();
        if (value == null) {
            return value;
        }
        return value.feeds;
    };

    factory.getFeedURL = function (value) {
        var feeds = factory.getFeeds();

        if (feeds == null) {
            return null;
        }

        for (i = 0; i < feeds.length; i++) {

            if (value == feeds[i].page) {
                return feeds[i].url;
            }
        }
        return null;
    }

    factory.getFeedTemplate = function (value) {
        var feeds = factory.getFeeds();

        if (feeds == null) {
            return null;
        }

        for (i = 0; i < feeds.length; i++) {

            if (value == feeds[i].page) {
                return feeds[i].displayType;
            }
        }
        return null;
    }

    return factory;
}];

app.factory('sharedDataService', sharedDataService);